"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPolyfillTargets = void 0;
const browser_compat_data_1 = __importDefault(require("@mdn/browser-compat-data"));
const lodash_get_1 = __importDefault(require("lodash.get"));
const semver_1 = __importDefault(require("semver"));
const mdn_to_browserslist_map_1 = require("./mdn_to_browserslist_map");
function createPolyfillTargets(options) {
    const polyfills = {};
    for (const [polyfillId, { features }] of Object.entries(options.polyfills)) {
        const targets = {};
        for (const featureId of features) {
            const compat = (0, lodash_get_1.default)(browser_compat_data_1.default, featureId);
            const support = compat?.__compat?.support ?? {};
            for (const mdnBrowserName of Object.keys(support)) {
                const browser = mdn_to_browserslist_map_1.MDN_TO_BROWSERSLIST_MAP.get(mdnBrowserName);
                if (browser == null) {
                    continue;
                }
                const [statement] = [support[mdnBrowserName]].flat();
                if (statement?.flags != null) {
                    continue;
                }
                let versionAdded = null;
                if (statement?.version_added === true || (statement?.version_added || '').startsWith('≤')) {
                    versionAdded = '1';
                }
                else if (typeof statement?.version_added === 'string' && statement.version_added !== 'preview') {
                    versionAdded = statement.version_added;
                }
                const versionAddedSemver = semver_1.default.coerce(versionAdded);
                if (versionAdded == null || versionAddedSemver == null) {
                    continue;
                }
                const targetVersion = targets[browser];
                const targetVersionSemver = semver_1.default.coerce(targetVersion);
                if (targetVersionSemver == null || semver_1.default.lte(targetVersionSemver, versionAddedSemver)) {
                    targets[browser] = versionAdded;
                }
            }
        }
        polyfills[polyfillId] = targets;
    }
    return polyfills;
}
exports.createPolyfillTargets = createPolyfillTargets;
