"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateProviderDataURI = void 0;
const core_1 = require("@babel/core");
const constants_1 = require("./constants");
function generateProviderDataURI({ definitions, packageName, sourceType }) {
    const statements = [];
    if (sourceType === constants_1.SOURCE_TYPE_COMMONJS) {
        statements.push(core_1.template.statement.ast(`
        var __importDefault = function (mod) {
          return (mod && mod.__esModule) ? mod : { "default": mod };
        };
      `));
        for (const packageEntry of Object.values(definitions)) {
            statements.push(core_1.template.statement(`
          var %%package_entry_value%% = __importDefault(require(%%package_name%%))[%%package_entry_key%%];
        `)({
                package_entry_key: core_1.types.stringLiteral(packageEntry),
                package_entry_value: core_1.types.identifier(`__${packageEntry}`),
                package_name: core_1.types.stringLiteral(packageName),
            }));
        }
    }
    else {
        statements.push(core_1.types.importDeclaration(Object.values(definitions).map((packageEntry) => {
            return core_1.types.importSpecifier(core_1.types.identifier(`__${packageEntry}`), core_1.types.identifier(packageEntry));
        }), core_1.types.stringLiteral(packageName)));
    }
    statements.push(core_1.template.statement.ast(`
      var __global = (function () {
        return typeof globalThis !== 'undefined'
          ? globalThis
          : typeof self !== 'undefined'
            ? self
            : typeof window !== 'undefined'
              ? window
              : typeof global !== 'undefined'
                ? global
                : Function('return this')();
      })();
    `));
    for (const [exportAs, packageEntry] of Object.entries(definitions)) {
        statements.push(core_1.template.statement(`
        __global.%%export_as%% = %%package_entry%%;
      `)({
            export_as: exportAs,
            package_entry: core_1.types.identifier(`__${packageEntry}`),
        }));
    }
    const result = (0, core_1.transformFromAstSync)(core_1.types.program(statements.flat()), void 0, {
        compact: true,
        minified: true,
        sourceMaps: false,
    });
    if (result == null || typeof result.code !== 'string') {
        throw new Error('Cannot generate data uri.');
    }
    const base64 = Buffer.from(result.code, 'utf-8').toString('base64');
    const dataUri = `data:text/javascript;base64,${base64}`;
    return dataUri;
}
exports.generateProviderDataURI = generateProviderDataURI;
