"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const helper_define_polyfill_provider_1 = __importDefault(require("@babel/helper-define-polyfill-provider"));
const constants_1 = require("./constants");
const create_polyfill_targets_1 = require("./create_polyfill_targets");
const generate_provider_import_ast_1 = require("./generate_provider_import_ast");
const inject_action_cache_1 = require("./inject_action_cache");
const is_polyfill_id_1 = require("./is_polyfill_id");
exports.default = (0, helper_define_polyfill_provider_1.default)(({ debug, shouldInjectPolyfill }, pluginOptions) => {
    return {
        entryGlobal(meta, _utils, path) {
            if (meta.kind !== 'import' || !(0, is_polyfill_id_1.isPolyfillId)(meta.source)) {
                return;
            }
            const polyfill = pluginOptions.polyfills[meta.source];
            if (polyfill == null || !shouldInjectPolyfill(meta.source)) {
                debug(null);
                path.remove();
                return;
            }
            const program = path.findParent((p) => p.isProgram());
            const insertActionCache = inject_action_cache_1.InjectActionCache.getInstance({ program });
            const sourceType = path.isImportDeclaration() ? constants_1.SOURCE_TYPE_MODULE : constants_1.SOURCE_TYPE_COMMONJS;
            for (const packageOptions of polyfill.packages) {
                insertActionCache.inject([{ packageOptions, sourceType }], ({ packageOptions, sourceType }) => {
                    debug(packageOptions.packageName);
                    path.insertBefore((0, generate_provider_import_ast_1.generateProviderImportAST)({ packageOptions, sourceType }));
                });
            }
            path.remove();
        },
        name: 'custom',
        polyfills: (0, create_polyfill_targets_1.createPolyfillTargets)(pluginOptions),
    };
});
